You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2004/10/07 20:00:21 UTC

svn commit: rev 54002 - incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config

Author: akarasulu
Date: Thu Oct  7 11:00:20 2004
New Revision: 54002

Added:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java
      - copied, changed from rev 53948, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigurationSet.java
Removed:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigurationSet.java
Modified:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfig.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java
Log:
Commit changes ...

 o renamed ConfigurationSet to ConfigSet to have naming consistency
 o added interface hierarch to SyntaxConfig
 o starting to formulate overall picture of how this will work



Copied: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java (from rev 53948, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigurationSet.java)
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfig.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfig.java	Thu Oct  7 11:00:20 2004
@@ -23,14 +23,46 @@
 
 
 /**
- * Document me.
+ * A syntax schema object configuration set.
  *
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
 public class SyntaxConfig implements SyntaxConfigSet
 {
-    public Syntax[] loadSyntaxes( SyntaxCheckerRegistry registry )
+    /** an empty array */
+    private final static String[] EMPTY_ARRAY = new String[0];
+
+
+    // ------------------------------------------------------------------------
+    // Configuration Set Methods
+    // ------------------------------------------------------------------------
+
+
+    public String getOwner()
+    {
+        return "uid=admin,ou=system";
+    }
+
+
+    public String getSchemaName()
+    {
+        return "core";
+    }
+
+
+    public String[] getDependentSchemas()
+    {
+        return EMPTY_ARRAY;
+    }
+
+
+    // ------------------------------------------------------------------------
+    // Syntax Configuration Set Methods
+    // ------------------------------------------------------------------------
+
+
+    public Syntax[] load( SyntaxCheckerRegistry registry )
     {
         MutableSyntax[] syntaxes = new MutableSyntax[54];
 
@@ -358,7 +390,7 @@
 
 
     /**
-     * Used to access protected mutators.
+     * Used to access protected mutators of BaseSyntax from within this class.
      */
     private static class MutableSyntax extends BaseSyntax
     {

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java	Thu Oct  7 11:00:20 2004
@@ -16,13 +16,18 @@
  */
 package org.apache.eve.schema.config;
 
+
+import org.apache.ldap.common.schema.Syntax;
+import org.apache.eve.schema.SyntaxCheckerRegistry;
+
+
 /**
  * Document me.
  *
- * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory
- *         Project</a>
+ * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface SyntaxConfigSet
+public interface SyntaxConfigSet extends ConfigSet
 {
+    Syntax[] load( SyntaxCheckerRegistry registry );
 }
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigurationSet.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java	Thu Oct  7 11:00:20 2004
@@ -24,18 +24,18 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface ConfigurationSet
+public interface ConfigSet
 {
     /**
      * Gets the name of the owner of the schema objects within this
-     * ConfigurationSet.
+     * ConfigSet.
      *
      * @return the identifier for the owner of this set's objects
      */
     String getOwner();
 
     /**
      * Gets the name of the logical schema the objects of this ConfigurationSet
      * belong to: e.g. krb5-kdc may be the logical LDAP schema name.
      *
      * @return the name of the logical schema
@@ -44,7 +44,7 @@
 
     /**
      * Gets the names of other schemas that this objects within this
      * ConfigurationSet depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *
      * @return the String names of schema dependencies
@@ -24,18 +24,18 @@
 
     /**
-     * Gets the name of the logical schema the objects of this ConfigurationSet
+     * Gets the name of the logical schema the objects of this ConfigSet
      * belong to: e.g. krb5-kdc may be the logical LDAP schema name.
      *
@@ -44,7 +44,7 @@
     /**
      * Gets the names of other schemas that this objects within this
-     * ConfigurationSet depends upon.  These dependent schemas are those
+     * ConfigSet depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfig.java
==============================================================================